package ch.std.jumpstart.integration;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.context.SpringBootTest.WebEnvironment;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.boot.web.server.LocalServerPort;
import org.springframework.core.env.Environment;

import ch.std.jumpstart.jpa.City;
import ch.std.jumpstart.repositories.CityRepository;

@SpringBootTest(webEnvironment = WebEnvironment.RANDOM_PORT)
@EntityScan(basePackages="ch.std.jumpstart")
public class JumpstartApplicationJpaTests {
	@LocalServerPort
	private int port;
	
	@Autowired
	Environment environment;
	
	@Autowired
	private TestRestTemplate restTemplate;
	
	@Autowired
	private CityRepository cityRepository;

	@BeforeEach
	public void setup() {
		City city = new City();
		city.setName("Bern");
		this.cityRepository.save(city);
	}
	
	@AfterEach
	public void tearDown() {
		this.cityRepository.deleteAll(); // achtung löscht jede instanz einzeln
	}
	
	@Test
	public void contextLoads() {
	}

	@Test
	public void testCityAutoCompleteController() throws Exception {
		String contextPath = environment.getProperty("server.servlet.contextPath", String.class, "/");
        String url = "http://localhost:" + port + contextPath + "/auto/citiesjpa?value=Bern";
		City[] cities = this.restTemplate.getForObject(url, City[].class);
		assertNotNull(cities);
		assertEquals(1, cities.length);
		City city = cities[0];
		assertNotNull(city);
		assertEquals("Bern", city.getName());
	}
}
